import { jsxs, jsx } from 'react/jsx-runtime';
import { useState, useMemo } from 'react';
import { selectors } from '@grafana/e2e-selectors';
import { useStyles2, Label, Input, BrowserLabel } from '@grafana/ui';
import { useMetricsBrowser } from './MetricsBrowserContext.mjs';
import { getStylesLabelSelector } from './styles.mjs';
import { METRIC_LABEL } from './types.mjs';

function LabelSelector() {
  const styles = useStyles2(getStylesLabelSelector);
  const [labelSearchTerm, setLabelSearchTerm] = useState("");
  const { labelKeys, selectedLabelKeys, onLabelKeyClick } = useMetricsBrowser();
  const filteredLabelKeys = useMemo(() => {
    return labelKeys.filter(
      (lk) => lk !== METRIC_LABEL && (selectedLabelKeys.includes(lk) || lk.includes(labelSearchTerm))
    );
  }, [labelKeys, labelSearchTerm, selectedLabelKeys]);
  return /* @__PURE__ */ jsxs("div", { className: styles.section, children: [
    /* @__PURE__ */ jsx(Label, { description: "Once label values are selected, only possible label combinations are shown.", children: "2. Select labels to search in" }),
    /* @__PURE__ */ jsx("div", { children: /* @__PURE__ */ jsx(
      Input,
      {
        onChange: (e) => setLabelSearchTerm(e.currentTarget.value),
        "aria-label": "Filter expression for label",
        value: labelSearchTerm,
        "data-testid": selectors.components.DataSource.Prometheus.queryEditor.code.metricsBrowser.labelNamesFilter
      }
    ) }),
    /* @__PURE__ */ jsx("div", { className: styles.list, style: { height: 120 }, children: filteredLabelKeys.map((label) => /* @__PURE__ */ jsx(
      BrowserLabel,
      {
        name: label,
        loading: false,
        active: selectedLabelKeys.includes(label),
        hidden: false,
        facets: void 0,
        onClick: (name) => {
          setLabelSearchTerm("");
          onLabelKeyClick(name);
        },
        searchTerm: labelSearchTerm
      },
      label
    )) })
  ] });
}

export { LabelSelector };
//# sourceMappingURL=LabelSelector.mjs.map
